#[switch_to]Expand description
Denotes to which state will the object transition into after this method
Usage:
#[switch_to(State1)]- or with multiple state slots:
#[switch_to(State1, State2, ...)]
This macro is consumed by the #[states] macro, and it basically guiding #[states] macro to:
- overwrite the return type of the methods generated by the
#[states]macro
hence, it is empty, because it delegates its job to #[states] macro
the reason for that delegation is: #[switch_to] macro needs the below from the encapsulating impl block for the methods
- name of the impl block (name of the struct)